@@ -91,9 +91,7 @@ sub _set_menu_select_editor {
 			$val_to_disp{$sel->{value}} = '<div class="with-icon ' . $sel->{iconCls} . '">' . $sel->{text} . '</div>'
 				if($sel->{iconCls});
 			
-      # This needs to be refactored into JS to be able to support mount_url prefix
-      # (GitHub Issue #114)
-			$val_to_disp{$sel->{value}} = '<img src="/assets/rapidapp/misc/static/s.gif" class="ra-icon-centered-16x16 ' . $sel->{iconCls} . '">'
+			$val_to_disp{$sel->{value}} = '<img src="assets/rapidapp/misc/static/s.gif" class="ra-icon-centered-16x16 ' . $sel->{iconCls} . '">'
 				if($sel->{iconCls} and jstrue($new->{render_icon_only}));
 		};
 	}
