@@ -415,6 +415,8 @@ sub create_module {
   my $class_name = shift;
   my $params = shift;
   
+  die "Bad module name '$name' -- cannot contain '/'" if ($name =~ /\//);
+
   Module::Runtime::require_module($class_name);
   
   $params = $self->create_module_params unless (defined $params);
@@ -943,6 +945,9 @@ sub controller_dispatch {
     if (defined $self->default_action);
   
   my $ct= $self->c->stash->{requestContentType};
+  
+  $self->_maybe_special_path_redirect($opt,@subargs) if ($opt);
+  
   # if there were unprocessed arguments which were not an action, and there was no default action, generate a 404
   # UPDATE: unless new 'accept_subargs' attr is true (see attribute declaration above)
   if (defined $opt && !$self->accept_subargs) {
@@ -990,6 +995,21 @@ sub controller_dispatch {
   
 }
 
+sub _maybe_special_path_redirect {
+  my ($self, $opt, @subargs)= @_;
+  my $c = $self->c;
+  
+  # Special handling for relative requests to special/reserved controller paths.
+  # This allows us to use relative paths in front-side code and for it to just
+  # work, even if we change our mount path later on
+  $c->redispatch_public_path($c->mount_url,$opt,@subargs) && $c->detach if (
+       $opt eq 'simplecas'
+    || $opt eq 'assets'
+    #|| $opt eq 'rapidapp'   #<-- we don't need this that much
+  );
+}
+
+
 # This call happens via local method so subclasses are able to override
 sub auto_hashnav_redirect_current {
   my $self = shift;
