@@ -18,7 +18,7 @@ use URI::Escape;
 use RapidApp;
 use Template;
 
-use Catalyst::Controller::SimpleCAS 0.995;
+use Catalyst::Controller::SimpleCAS 0.998;
 
 sub rapidapp_version { $RapidApp::VERSION }
 
@@ -312,7 +312,7 @@ sub hashnav_redirect {
     $url .= '?' . $qs;
   }
 
-  $c->response->redirect($url);
+  $c->response->redirect($c->mount_url.$url);
   return $c->detach;
 }
 
